 • text: Plain text (can also be code).
 • inline_data: Inlined bytes data (e.g., binary blobs).
 • file_data: URI-based data (e.g., a file reference).
 • video_metadata: Metadata for a video.
 • code_execution_result: The result of executing code (stdout, stderr, etc.).
 • executable_code: Code generated by the model, meant to be executed.
 • function_call: A predicted function call (name and arguments).
 • function_response: The result/output of a function call.
 • thought: A boolean flag indicating if the part is a "thought" from the model.